#
# spec file for package python-python-gnupg
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
Name:           python-python-gnupg
Version:        0.4.4
Release:        lp151.2.1
Summary:        A wrapper for the GNU Privacy Guard (GPG or GnuPG)
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://pythonhosted.org/python-gnupg/index.html
Source:         https://files.pythonhosted.org/packages/source/p/python-gnupg/python-gnupg-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  gpg2
BuildRequires:  python-rpm-macros
Requires:       gpg2
Obsoletes:      python-gnupg < %{version}
Provides:       python-gnupg = %{version}
BuildArch:      noarch
%ifpython2
Obsoletes:      %{oldpython}-gnupg < %{version}
Provides:       %{oldpython}-gnupg = %{version}
%endif
%python_subpackages

%description
This module allows access to GnuPG's key management,
encryption and signature functionality from Python programs.

%prep
%setup -q -n python-gnupg-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export NO_EXTERNAL_TESTS=true
%python_expand py.test-%{$python_bin_suffix} -v test_gnupg.py

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*

%changelog
* Tue Apr 16 2019 Matej Cepl <mcepl@suse.com>
- bsc#1130083: Switch to pytest runner, which seems to be a way
  more stable in providing the results.
* Thu Jan 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable tests
* Thu Jan 24 2019 Karol Babioch <kbabioch@suse.de>
- Update to 0.4.4:
  * Changed how any return value from the ``on_data`` callable is processed. In
    earlier versions, the return value was ignored. In this version, if the
    return value is ``False``, the data received from ``gpg`` is not buffered.
    Otherwise (if the value is ``None`` or ``True``, for example), the data is
    buffered as normal. This functionality can be used to do your own
    buffering, or to prevent buffering altogether.  The ``on_data`` callable is
    also called once with an empty byte-string to signal the end of data from
    ``gpg``.
  * Added an additional attribute ``check_fingerprint_collisions`` to
    ``GPG`` instances, which defaults to ``False``. It seems that ``gpg`` is
    happy to have duplicate keys and fingerprints in a keyring, so we can't be
    too strict. A user can set this attribute of an instance to ``True`` to
    trigger a check for collisions.
  * With GnuPG 2.2.7 or later, provide the fingerprint of a signing key for a
    failed signature verification, if available.
  * For verification where multiple signatures are involved, a mapping of
    signature_ids to fingerprint, keyid, username, creation date, creation
    timestamp and expiry timestamp is provided.
  * Added a check to disallow certain control characters ('\r', '\n', NUL) in
    passphrases (CVE-2019-6690 bsc#1123498)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jun 13 2018 astieger@suse.com
- uppate to 0.4.3:
  * Add --no-verbose to the gpg command line, in case verbose is
    specified is gpg.conf.
  * This is mitigation against CVE-2018-12020 boo#1096745
- includes changes from 0.4.2:
  * Subkey information is now collected and returned in a
    subkey_info dictionary keyed by the subkey's ID
  * Add expect_passphrase password for use on GnuPG >= 2.1 when
    passing passphrase to gpg via pinentry
  * Provid a trust_keys method to allow setting the trust level
    for keys
  * When the gpg executable is not found, note the path used in the
    exception message
  * Make error messages nor informational
* Mon Sep 11 2017 jengelh@inai.de
- Ensure description neutrality.
* Wed Sep  6 2017 toddrme2178@gmail.com
- Initial version
